# `keras`-like Package

[![InAccel](https://img.shields.io/static/v1?label=InAccel&message=FPGA&color=important)](https://inaccel.com)
[![PyPI version](https://badge.fury.io/py/inaccel-keras.svg)](https://badge.fury.io/py/inaccel-keras)
